@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -51,10 +49,9 @@ from google.cloud.automl_v1.types import text
 from google.cloud.automl_v1.types import text_extraction
 from google.cloud.automl_v1.types import text_sentiment
 from google.cloud.automl_v1.types import translation
-from google.protobuf import empty_pb2 as empty  # type: ignore
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import AutoMlTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import AutoMlGrpcTransport
 from .transports.grpc_asyncio import AutoMlGrpcAsyncIOTransport
@@ -73,7 +70,7 @@ class AutoMlClientMeta(type):
     _transport_registry["grpc_asyncio"] = AutoMlGrpcAsyncIOTransport
 
     def get_transport_class(cls, label: str = None,) -> Type[AutoMlTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -111,7 +108,8 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -145,7 +143,8 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -162,7 +161,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -181,10 +180,11 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     @property
     def transport(self) -> AutoMlTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            AutoMlTransport: The transport used by the client instance.
+            AutoMlTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
@@ -192,7 +192,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
     def annotation_spec_path(
         project: str, location: str, dataset: str, annotation_spec: str,
     ) -> str:
-        """Return a fully-qualified annotation_spec string."""
+        """Returns a fully-qualified annotation_spec string."""
         return "projects/{project}/locations/{location}/datasets/{dataset}/annotationSpecs/{annotation_spec}".format(
             project=project,
             location=location,
@@ -202,7 +202,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     @staticmethod
     def parse_annotation_spec_path(path: str) -> Dict[str, str]:
-        """Parse a annotation_spec path into its component segments."""
+        """Parses a annotation_spec path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/datasets/(?P<dataset>.+?)/annotationSpecs/(?P<annotation_spec>.+?)$",
             path,
@@ -211,14 +211,14 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     @staticmethod
     def dataset_path(project: str, location: str, dataset: str,) -> str:
-        """Return a fully-qualified dataset string."""
+        """Returns a fully-qualified dataset string."""
         return "projects/{project}/locations/{location}/datasets/{dataset}".format(
             project=project, location=location, dataset=dataset,
         )
 
     @staticmethod
     def parse_dataset_path(path: str) -> Dict[str, str]:
-        """Parse a dataset path into its component segments."""
+        """Parses a dataset path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/datasets/(?P<dataset>.+?)$",
             path,
@@ -227,14 +227,14 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     @staticmethod
     def model_path(project: str, location: str, model: str,) -> str:
-        """Return a fully-qualified model string."""
+        """Returns a fully-qualified model string."""
         return "projects/{project}/locations/{location}/models/{model}".format(
             project=project, location=location, model=model,
         )
 
     @staticmethod
     def parse_model_path(path: str) -> Dict[str, str]:
-        """Parse a model path into its component segments."""
+        """Parses a model path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/models/(?P<model>.+?)$",
             path,
@@ -245,7 +245,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
     def model_evaluation_path(
         project: str, location: str, model: str, model_evaluation: str,
     ) -> str:
-        """Return a fully-qualified model_evaluation string."""
+        """Returns a fully-qualified model_evaluation string."""
         return "projects/{project}/locations/{location}/models/{model}/modelEvaluations/{model_evaluation}".format(
             project=project,
             location=location,
@@ -255,7 +255,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     @staticmethod
     def parse_model_evaluation_path(path: str) -> Dict[str, str]:
-        """Parse a model_evaluation path into its component segments."""
+        """Parses a model_evaluation path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/models/(?P<model>.+?)/modelEvaluations/(?P<model_evaluation>.+?)$",
             path,
@@ -264,7 +264,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -277,7 +277,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -288,7 +288,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -299,7 +299,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -310,7 +310,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -324,12 +324,12 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, AutoMlTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the auto ml client.
+        """Instantiates the auto ml client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -384,9 +384,10 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 client_cert_source_func = client_options.client_cert_source
             else:
                 is_mtls = mtls.has_default_client_cert_source()
-                client_cert_source_func = (
-                    mtls.default_client_cert_source() if is_mtls else None
-                )
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -398,12 +399,14 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -418,8 +421,8 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -462,7 +465,6 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 This corresponds to the ``dataset`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -493,10 +495,8 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         # there are no flattened fields.
         if not isinstance(request, service.CreateDatasetRequest):
             request = service.CreateDatasetRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if dataset is not None:
@@ -548,7 +548,6 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -579,10 +578,8 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         # there are no flattened fields.
         if not isinstance(request, service.GetDatasetRequest):
             request = service.GetDatasetRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -624,7 +621,6 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -656,10 +652,8 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         # there are no flattened fields.
         if not isinstance(request, service.ListDatasetsRequest):
             request = service.ListDatasetsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -690,7 +684,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         request: service.UpdateDatasetRequest = None,
         *,
         dataset: gca_dataset.Dataset = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -715,7 +709,6 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -746,10 +739,8 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         # there are no flattened fields.
         if not isinstance(request, service.UpdateDatasetRequest):
             request = service.UpdateDatasetRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if dataset is not None:
                 request.dataset = dataset
             if update_mask is not None:
@@ -799,7 +790,6 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -841,10 +831,8 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         # there are no flattened fields.
         if not isinstance(request, service.DeleteDatasetRequest):
             request = service.DeleteDatasetRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -865,7 +853,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         response = operation.from_gapic(
             response,
             self._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=operations.OperationMetadata,
         )
 
@@ -913,7 +901,6 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 This corresponds to the ``input_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -955,10 +942,8 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         # there are no flattened fields.
         if not isinstance(request, service.ImportDataRequest):
             request = service.ImportDataRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
             if input_config is not None:
@@ -981,7 +966,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         response = operation.from_gapic(
             response,
             self._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=operations.OperationMetadata,
         )
 
@@ -1021,7 +1006,6 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 This corresponds to the ``output_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1063,10 +1047,8 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         # there are no flattened fields.
         if not isinstance(request, service.ExportDataRequest):
             request = service.ExportDataRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
             if output_config is not None:
@@ -1089,7 +1071,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         response = operation.from_gapic(
             response,
             self._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=operations.OperationMetadata,
         )
 
@@ -1118,7 +1100,6 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1145,10 +1126,8 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         # there are no flattened fields.
         if not isinstance(request, service.GetAnnotationSpecRequest):
             request = service.GetAnnotationSpecRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1201,7 +1180,6 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 This corresponds to the ``model`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1233,10 +1211,8 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         # there are no flattened fields.
         if not isinstance(request, service.CreateModelRequest):
             request = service.CreateModelRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if model is not None:
@@ -1286,7 +1262,6 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1315,10 +1290,8 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         # there are no flattened fields.
         if not isinstance(request, service.GetModelRequest):
             request = service.GetModelRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1360,7 +1333,6 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1392,10 +1364,8 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         # there are no flattened fields.
         if not isinstance(request, service.ListModelsRequest):
             request = service.ListModelsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -1446,7 +1416,6 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1488,10 +1457,8 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         # there are no flattened fields.
         if not isinstance(request, service.DeleteModelRequest):
             request = service.DeleteModelRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1512,7 +1479,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         response = operation.from_gapic(
             response,
             self._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=operations.OperationMetadata,
         )
 
@@ -1524,7 +1491,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         request: service.UpdateModelRequest = None,
         *,
         model: gca_model.Model = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -1549,7 +1516,6 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1578,10 +1544,8 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         # there are no flattened fields.
         if not isinstance(request, service.UpdateModelRequest):
             request = service.UpdateModelRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if model is not None:
                 request.model = model
             if update_mask is not None:
@@ -1641,7 +1605,6 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1683,10 +1646,8 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         # there are no flattened fields.
         if not isinstance(request, service.DeployModelRequest):
             request = service.DeployModelRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1707,7 +1668,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         response = operation.from_gapic(
             response,
             self._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=operations.OperationMetadata,
         )
 
@@ -1744,7 +1705,6 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1786,10 +1746,8 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         # there are no flattened fields.
         if not isinstance(request, service.UndeployModelRequest):
             request = service.UndeployModelRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1810,7 +1768,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         response = operation.from_gapic(
             response,
             self._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=operations.OperationMetadata,
         )
 
@@ -1856,7 +1814,6 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 This corresponds to the ``output_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1898,10 +1855,8 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         # there are no flattened fields.
         if not isinstance(request, service.ExportModelRequest):
             request = service.ExportModelRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
             if output_config is not None:
@@ -1924,7 +1879,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         response = operation.from_gapic(
             response,
             self._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=operations.OperationMetadata,
         )
 
@@ -1953,7 +1908,6 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1980,10 +1934,8 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         # there are no flattened fields.
         if not isinstance(request, service.GetModelEvaluationRequest):
             request = service.GetModelEvaluationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -2047,7 +1999,6 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 This corresponds to the ``filter`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -2079,10 +2030,8 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         # there are no flattened fields.
         if not isinstance(request, service.ListModelEvaluationsRequest):
             request = service.ListModelEvaluationsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if filter is not None:
