@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,10 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.automl_v1.types import geometry
 from google.cloud.automl_v1.types import io
 from google.cloud.automl_v1.types import text_segment as gca_text_segment
@@ -48,14 +45,12 @@ class Image(proto.Message):
             Output only. HTTP URI to the thumbnail image.
     """
 
-    image_bytes = proto.Field(proto.BYTES, number=1, oneof="data")
-
-    thumbnail_uri = proto.Field(proto.STRING, number=4)
+    image_bytes = proto.Field(proto.BYTES, number=1, oneof="data",)
+    thumbnail_uri = proto.Field(proto.STRING, number=4,)
 
 
 class TextSnippet(proto.Message):
     r"""A representation of a text snippet.
-
     Attributes:
         content (str):
             Required. The content of the text snippet as
@@ -72,16 +67,13 @@ class TextSnippet(proto.Message):
             the content.
     """
 
-    content = proto.Field(proto.STRING, number=1)
-
-    mime_type = proto.Field(proto.STRING, number=2)
-
-    content_uri = proto.Field(proto.STRING, number=4)
+    content = proto.Field(proto.STRING, number=1,)
+    mime_type = proto.Field(proto.STRING, number=2,)
+    content_uri = proto.Field(proto.STRING, number=4,)
 
 
 class DocumentDimensions(proto.Message):
     r"""Message that describes dimension of a document.
-
     Attributes:
         unit (google.cloud.automl_v1.types.DocumentDimensions.DocumentDimensionUnit):
             Unit of the dimension.
@@ -101,15 +93,12 @@ class DocumentDimensions(proto.Message):
         POINT = 3
 
     unit = proto.Field(proto.ENUM, number=1, enum=DocumentDimensionUnit,)
-
-    width = proto.Field(proto.FLOAT, number=2)
-
-    height = proto.Field(proto.FLOAT, number=3)
+    width = proto.Field(proto.FLOAT, number=2,)
+    height = proto.Field(proto.FLOAT, number=3,)
 
 
 class Document(proto.Message):
     r"""A structured text document e.g. a PDF.
-
     Attributes:
         input_config (google.cloud.automl_v1.types.DocumentInputConfig):
             An input config specifying the content of the
@@ -173,33 +162,25 @@ class Document(proto.Message):
         text_segment = proto.Field(
             proto.MESSAGE, number=1, message=gca_text_segment.TextSegment,
         )
-
-        page_number = proto.Field(proto.INT32, number=2)
-
+        page_number = proto.Field(proto.INT32, number=2,)
         bounding_poly = proto.Field(
             proto.MESSAGE, number=3, message=geometry.BoundingPoly,
         )
-
         text_segment_type = proto.Field(
             proto.ENUM, number=4, enum="Document.Layout.TextSegmentType",
         )
 
     input_config = proto.Field(proto.MESSAGE, number=1, message=io.DocumentInputConfig,)
-
     document_text = proto.Field(proto.MESSAGE, number=2, message="TextSnippet",)
-
     layout = proto.RepeatedField(proto.MESSAGE, number=3, message=Layout,)
-
     document_dimensions = proto.Field(
         proto.MESSAGE, number=4, message="DocumentDimensions",
     )
-
-    page_count = proto.Field(proto.INT32, number=5)
+    page_count = proto.Field(proto.INT32, number=5,)
 
 
 class ExamplePayload(proto.Message):
     r"""Example data used for training or prediction.
-
     Attributes:
         image (google.cloud.automl_v1.types.Image):
             Example image.
@@ -210,11 +191,9 @@ class ExamplePayload(proto.Message):
     """
 
     image = proto.Field(proto.MESSAGE, number=1, oneof="payload", message="Image",)
-
     text_snippet = proto.Field(
         proto.MESSAGE, number=2, oneof="payload", message="TextSnippet",
     )
-
     document = proto.Field(
         proto.MESSAGE, number=4, oneof="payload", message="Document",
     )
