@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
 
@@ -738,8 +736,7 @@ class InputConfig(proto.Message):
     gcs_source = proto.Field(
         proto.MESSAGE, number=1, oneof="source", message="GcsSource",
     )
-
-    params = proto.MapField(proto.STRING, proto.STRING, number=2)
+    params = proto.MapField(proto.STRING, proto.STRING, number=2,)
 
 
 class BatchPredictInputConfig(proto.Message):
@@ -1449,7 +1446,6 @@ class BatchPredictOutputConfig(proto.Message):
 
 class ModelExportOutputConfig(proto.Message):
     r"""Output configuration for ModelExport Action.
-
     Attributes:
         gcs_destination (google.cloud.automl_v1.types.GcsDestination):
             Required. The Google Cloud Storage location where the model
@@ -1516,15 +1512,12 @@ class ModelExportOutputConfig(proto.Message):
     gcs_destination = proto.Field(
         proto.MESSAGE, number=1, oneof="destination", message="GcsDestination",
     )
-
-    model_format = proto.Field(proto.STRING, number=4)
-
-    params = proto.MapField(proto.STRING, proto.STRING, number=2)
+    model_format = proto.Field(proto.STRING, number=4,)
+    params = proto.MapField(proto.STRING, proto.STRING, number=2,)
 
 
 class GcsSource(proto.Message):
     r"""The Google Cloud Storage location for the input content.
-
     Attributes:
         input_uris (Sequence[str]):
             Required. Google Cloud Storage URIs to input files, up to
@@ -1533,7 +1526,7 @@ class GcsSource(proto.Message):
             -  Full object path, e.g. gs://bucket/directory/object.csv
     """
 
-    input_uris = proto.RepeatedField(proto.STRING, number=1)
+    input_uris = proto.RepeatedField(proto.STRING, number=1,)
 
 
 class GcsDestination(proto.Message):
@@ -1550,7 +1543,7 @@ class GcsDestination(proto.Message):
                is created if it doesn't exist.
     """
 
-    output_uri_prefix = proto.Field(proto.STRING, number=1)
+    output_uri_prefix = proto.Field(proto.STRING, number=1,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
