@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,13 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.automl_v1beta1.types import io
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-from google.rpc import status_pb2 as status  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+from google.rpc import status_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -83,97 +80,84 @@ class OperationMetadata(proto.Message):
     delete_details = proto.Field(
         proto.MESSAGE, number=8, oneof="details", message="DeleteOperationMetadata",
     )
-
     deploy_model_details = proto.Field(
         proto.MESSAGE,
         number=24,
         oneof="details",
         message="DeployModelOperationMetadata",
     )
-
     undeploy_model_details = proto.Field(
         proto.MESSAGE,
         number=25,
         oneof="details",
         message="UndeployModelOperationMetadata",
     )
-
     create_model_details = proto.Field(
         proto.MESSAGE,
         number=10,
         oneof="details",
         message="CreateModelOperationMetadata",
     )
-
     import_data_details = proto.Field(
         proto.MESSAGE,
         number=15,
         oneof="details",
         message="ImportDataOperationMetadata",
     )
-
     batch_predict_details = proto.Field(
         proto.MESSAGE,
         number=16,
         oneof="details",
         message="BatchPredictOperationMetadata",
     )
-
     export_data_details = proto.Field(
         proto.MESSAGE,
         number=21,
         oneof="details",
         message="ExportDataOperationMetadata",
     )
-
     export_model_details = proto.Field(
         proto.MESSAGE,
         number=22,
         oneof="details",
         message="ExportModelOperationMetadata",
     )
-
     export_evaluated_examples_details = proto.Field(
         proto.MESSAGE,
         number=26,
         oneof="details",
         message="ExportEvaluatedExamplesOperationMetadata",
     )
-
-    progress_percent = proto.Field(proto.INT32, number=13)
-
+    progress_percent = proto.Field(proto.INT32, number=13,)
     partial_failures = proto.RepeatedField(
-        proto.MESSAGE, number=2, message=status.Status,
+        proto.MESSAGE, number=2, message=status_pb2.Status,
     )
-
-    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp.Timestamp,)
-
-    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp.Timestamp,)
+    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
+    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
 
 
 class DeleteOperationMetadata(proto.Message):
-    r"""Details of operations that perform deletes of any entities."""
+    r"""Details of operations that perform deletes of any entities.    """
 
 
 class DeployModelOperationMetadata(proto.Message):
-    r"""Details of DeployModel operation."""
+    r"""Details of DeployModel operation.    """
 
 
 class UndeployModelOperationMetadata(proto.Message):
-    r"""Details of UndeployModel operation."""
+    r"""Details of UndeployModel operation.    """
 
 
 class CreateModelOperationMetadata(proto.Message):
-    r"""Details of CreateModel operation."""
+    r"""Details of CreateModel operation.    """
 
 
 class ImportDataOperationMetadata(proto.Message):
-    r"""Details of ImportData operation."""
+    r"""Details of ImportData operation.    """
 
 
 class ExportDataOperationMetadata(proto.Message):
     r"""Details of ExportData operation.
-
     Attributes:
         output_info (google.cloud.automl_v1beta1.types.ExportDataOperationMetadata.ExportDataOutputInfo):
             Output only. Information further describing
@@ -196,11 +180,10 @@ class ExportDataOperationMetadata(proto.Message):
         """
 
         gcs_output_directory = proto.Field(
-            proto.STRING, number=1, oneof="output_location"
+            proto.STRING, number=1, oneof="output_location",
         )
-
         bigquery_output_dataset = proto.Field(
-            proto.STRING, number=2, oneof="output_location"
+            proto.STRING, number=2, oneof="output_location",
         )
 
     output_info = proto.Field(proto.MESSAGE, number=1, message=ExportDataOutputInfo,)
@@ -208,7 +191,6 @@ class ExportDataOperationMetadata(proto.Message):
 
 class BatchPredictOperationMetadata(proto.Message):
     r"""Details of BatchPredict operation.
-
     Attributes:
         input_config (google.cloud.automl_v1beta1.types.BatchPredictInputConfig):
             Output only. The input config that was given
@@ -235,23 +217,20 @@ class BatchPredictOperationMetadata(proto.Message):
         """
 
         gcs_output_directory = proto.Field(
-            proto.STRING, number=1, oneof="output_location"
+            proto.STRING, number=1, oneof="output_location",
         )
-
         bigquery_output_dataset = proto.Field(
-            proto.STRING, number=2, oneof="output_location"
+            proto.STRING, number=2, oneof="output_location",
         )
 
     input_config = proto.Field(
         proto.MESSAGE, number=1, message=io.BatchPredictInputConfig,
     )
-
     output_info = proto.Field(proto.MESSAGE, number=2, message=BatchPredictOutputInfo,)
 
 
 class ExportModelOperationMetadata(proto.Message):
     r"""Details of ExportModel operation.
-
     Attributes:
         output_info (google.cloud.automl_v1beta1.types.ExportModelOperationMetadata.ExportModelOutputInfo):
             Output only. Information further describing
@@ -270,14 +249,13 @@ class ExportModelOperationMetadata(proto.Message):
                 exported.
         """
 
-        gcs_output_directory = proto.Field(proto.STRING, number=1)
+        gcs_output_directory = proto.Field(proto.STRING, number=1,)
 
     output_info = proto.Field(proto.MESSAGE, number=2, message=ExportModelOutputInfo,)
 
 
 class ExportEvaluatedExamplesOperationMetadata(proto.Message):
     r"""Details of EvaluatedExamples operation.
-
     Attributes:
         output_info (google.cloud.automl_v1beta1.types.ExportEvaluatedExamplesOperationMetadata.ExportEvaluatedExamplesOutputInfo):
             Output only. Information further describing
@@ -298,7 +276,7 @@ class ExportEvaluatedExamplesOperationMetadata(proto.Message):
                 written.
         """
 
-        bigquery_output_dataset = proto.Field(proto.STRING, number=2)
+        bigquery_output_dataset = proto.Field(proto.STRING, number=2,)
 
     output_info = proto.Field(
         proto.MESSAGE, number=2, message=ExportEvaluatedExamplesOutputInfo,
