@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
 
@@ -25,7 +23,6 @@ __protobuf__ = proto.module(
 
 class DoubleRange(proto.Message):
     r"""A range between two double numbers.
-
     Attributes:
         start (float):
             Start of the range, inclusive.
@@ -33,9 +30,8 @@ class DoubleRange(proto.Message):
             End of the range, exclusive.
     """
 
-    start = proto.Field(proto.DOUBLE, number=1)
-
-    end = proto.Field(proto.DOUBLE, number=2)
+    start = proto.Field(proto.DOUBLE, number=1,)
+    end = proto.Field(proto.DOUBLE, number=2,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
