@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,10 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.automl_v1beta1.types import column_spec as gca_column_spec
 from google.cloud.automl_v1beta1.types import dataset as gca_dataset
 from google.cloud.automl_v1beta1.types import image
@@ -25,7 +22,7 @@ from google.cloud.automl_v1beta1.types import io
 from google.cloud.automl_v1beta1.types import model as gca_model
 from google.cloud.automl_v1beta1.types import model_evaluation as gca_model_evaluation
 from google.cloud.automl_v1beta1.types import table_spec as gca_table_spec
-from google.protobuf import field_mask_pb2 as gp_field_mask  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -76,8 +73,7 @@ class CreateDatasetRequest(proto.Message):
             Required. The dataset to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
+    parent = proto.Field(proto.STRING, number=1,)
     dataset = proto.Field(proto.MESSAGE, number=2, message=gca_dataset.Dataset,)
 
 
@@ -91,7 +87,7 @@ class GetDatasetRequest(proto.Message):
             retrieve.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class ListDatasetsRequest(proto.Message):
@@ -124,13 +120,10 @@ class ListDatasetsRequest(proto.Message):
             call.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    filter = proto.Field(proto.STRING, number=3)
-
-    page_size = proto.Field(proto.INT32, number=4)
-
-    page_token = proto.Field(proto.STRING, number=6)
+    parent = proto.Field(proto.STRING, number=1,)
+    filter = proto.Field(proto.STRING, number=3,)
+    page_size = proto.Field(proto.INT32, number=4,)
+    page_token = proto.Field(proto.STRING, number=6,)
 
 
 class ListDatasetsResponse(proto.Message):
@@ -153,8 +146,7 @@ class ListDatasetsResponse(proto.Message):
     datasets = proto.RepeatedField(
         proto.MESSAGE, number=1, message=gca_dataset.Dataset,
     )
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class UpdateDatasetRequest(proto.Message):
@@ -170,8 +162,9 @@ class UpdateDatasetRequest(proto.Message):
     """
 
     dataset = proto.Field(proto.MESSAGE, number=1, message=gca_dataset.Dataset,)
-
-    update_mask = proto.Field(proto.MESSAGE, number=2, message=gp_field_mask.FieldMask,)
+    update_mask = proto.Field(
+        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    )
 
 
 class DeleteDatasetRequest(proto.Message):
@@ -184,7 +177,7 @@ class DeleteDatasetRequest(proto.Message):
             delete.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class ImportDataRequest(proto.Message):
@@ -201,8 +194,7 @@ class ImportDataRequest(proto.Message):
             domain specific semantics, if any.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
+    name = proto.Field(proto.STRING, number=1,)
     input_config = proto.Field(proto.MESSAGE, number=3, message=io.InputConfig,)
 
 
@@ -217,8 +209,7 @@ class ExportDataRequest(proto.Message):
             Required. The desired output location.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
+    name = proto.Field(proto.STRING, number=1,)
     output_config = proto.Field(proto.MESSAGE, number=3, message=io.OutputConfig,)
 
 
@@ -232,7 +223,7 @@ class GetAnnotationSpecRequest(proto.Message):
             spec to retrieve.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class GetTableSpecRequest(proto.Message):
@@ -247,9 +238,8 @@ class GetTableSpecRequest(proto.Message):
             Mask specifying which fields to read.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    field_mask = proto.Field(proto.MESSAGE, number=2, message=gp_field_mask.FieldMask,)
+    name = proto.Field(proto.STRING, number=1,)
+    field_mask = proto.Field(proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,)
 
 
 class ListTableSpecsRequest(proto.Message):
@@ -277,15 +267,11 @@ class ListTableSpecsRequest(proto.Message):
             call.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    field_mask = proto.Field(proto.MESSAGE, number=2, message=gp_field_mask.FieldMask,)
-
-    filter = proto.Field(proto.STRING, number=3)
-
-    page_size = proto.Field(proto.INT32, number=4)
-
-    page_token = proto.Field(proto.STRING, number=6)
+    parent = proto.Field(proto.STRING, number=1,)
+    field_mask = proto.Field(proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,)
+    filter = proto.Field(proto.STRING, number=3,)
+    page_size = proto.Field(proto.INT32, number=4,)
+    page_token = proto.Field(proto.STRING, number=6,)
 
 
 class ListTableSpecsResponse(proto.Message):
@@ -308,8 +294,7 @@ class ListTableSpecsResponse(proto.Message):
     table_specs = proto.RepeatedField(
         proto.MESSAGE, number=1, message=gca_table_spec.TableSpec,
     )
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class UpdateTableSpecRequest(proto.Message):
@@ -325,8 +310,9 @@ class UpdateTableSpecRequest(proto.Message):
     """
 
     table_spec = proto.Field(proto.MESSAGE, number=1, message=gca_table_spec.TableSpec,)
-
-    update_mask = proto.Field(proto.MESSAGE, number=2, message=gp_field_mask.FieldMask,)
+    update_mask = proto.Field(
+        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    )
 
 
 class GetColumnSpecRequest(proto.Message):
@@ -341,9 +327,8 @@ class GetColumnSpecRequest(proto.Message):
             Mask specifying which fields to read.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    field_mask = proto.Field(proto.MESSAGE, number=2, message=gp_field_mask.FieldMask,)
+    name = proto.Field(proto.STRING, number=1,)
+    field_mask = proto.Field(proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,)
 
 
 class ListColumnSpecsRequest(proto.Message):
@@ -371,15 +356,11 @@ class ListColumnSpecsRequest(proto.Message):
             call.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    field_mask = proto.Field(proto.MESSAGE, number=2, message=gp_field_mask.FieldMask,)
-
-    filter = proto.Field(proto.STRING, number=3)
-
-    page_size = proto.Field(proto.INT32, number=4)
-
-    page_token = proto.Field(proto.STRING, number=6)
+    parent = proto.Field(proto.STRING, number=1,)
+    field_mask = proto.Field(proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,)
+    filter = proto.Field(proto.STRING, number=3,)
+    page_size = proto.Field(proto.INT32, number=4,)
+    page_token = proto.Field(proto.STRING, number=6,)
 
 
 class ListColumnSpecsResponse(proto.Message):
@@ -402,8 +383,7 @@ class ListColumnSpecsResponse(proto.Message):
     column_specs = proto.RepeatedField(
         proto.MESSAGE, number=1, message=gca_column_spec.ColumnSpec,
     )
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class UpdateColumnSpecRequest(proto.Message):
@@ -421,8 +401,9 @@ class UpdateColumnSpecRequest(proto.Message):
     column_spec = proto.Field(
         proto.MESSAGE, number=1, message=gca_column_spec.ColumnSpec,
     )
-
-    update_mask = proto.Field(proto.MESSAGE, number=2, message=gp_field_mask.FieldMask,)
+    update_mask = proto.Field(
+        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    )
 
 
 class CreateModelRequest(proto.Message):
@@ -437,8 +418,7 @@ class CreateModelRequest(proto.Message):
             Required. The model to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
+    parent = proto.Field(proto.STRING, number=1,)
     model = proto.Field(proto.MESSAGE, number=4, message=gca_model.Model,)
 
 
@@ -451,7 +431,7 @@ class GetModelRequest(proto.Message):
             Required. Resource name of the model.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class ListModelsRequest(proto.Message):
@@ -487,13 +467,10 @@ class ListModelsRequest(proto.Message):
             call.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    filter = proto.Field(proto.STRING, number=3)
-
-    page_size = proto.Field(proto.INT32, number=4)
-
-    page_token = proto.Field(proto.STRING, number=6)
+    parent = proto.Field(proto.STRING, number=1,)
+    filter = proto.Field(proto.STRING, number=3,)
+    page_size = proto.Field(proto.INT32, number=4,)
+    page_token = proto.Field(proto.STRING, number=6,)
 
 
 class ListModelsResponse(proto.Message):
@@ -514,8 +491,7 @@ class ListModelsResponse(proto.Message):
         return self
 
     model = proto.RepeatedField(proto.MESSAGE, number=1, message=gca_model.Model,)
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class DeleteModelRequest(proto.Message):
@@ -528,7 +504,7 @@ class DeleteModelRequest(proto.Message):
             deleted.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class DeployModelRequest(proto.Message):
@@ -553,15 +529,13 @@ class DeployModelRequest(proto.Message):
         oneof="model_deployment_metadata",
         message=image.ImageObjectDetectionModelDeploymentMetadata,
     )
-
     image_classification_model_deployment_metadata = proto.Field(
         proto.MESSAGE,
         number=4,
         oneof="model_deployment_metadata",
         message=image.ImageClassificationModelDeploymentMetadata,
     )
-
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class UndeployModelRequest(proto.Message):
@@ -574,7 +548,7 @@ class UndeployModelRequest(proto.Message):
             undeploy.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class ExportModelRequest(proto.Message):
@@ -592,8 +566,7 @@ class ExportModelRequest(proto.Message):
             configuration.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
+    name = proto.Field(proto.STRING, number=1,)
     output_config = proto.Field(
         proto.MESSAGE, number=3, message=io.ModelExportOutputConfig,
     )
@@ -612,8 +585,7 @@ class ExportEvaluatedExamplesRequest(proto.Message):
             configuration.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
+    name = proto.Field(proto.STRING, number=1,)
     output_config = proto.Field(
         proto.MESSAGE, number=3, message=io.ExportEvaluatedExamplesOutputConfig,
     )
@@ -629,7 +601,7 @@ class GetModelEvaluationRequest(proto.Message):
             evaluation.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class ListModelEvaluationsRequest(proto.Message):
@@ -665,13 +637,10 @@ class ListModelEvaluationsRequest(proto.Message):
             call.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    filter = proto.Field(proto.STRING, number=3)
-
-    page_size = proto.Field(proto.INT32, number=4)
-
-    page_token = proto.Field(proto.STRING, number=6)
+    parent = proto.Field(proto.STRING, number=1,)
+    filter = proto.Field(proto.STRING, number=3,)
+    page_size = proto.Field(proto.INT32, number=4,)
+    page_token = proto.Field(proto.STRING, number=6,)
 
 
 class ListModelEvaluationsResponse(proto.Message):
@@ -697,8 +666,7 @@ class ListModelEvaluationsResponse(proto.Message):
     model_evaluation = proto.RepeatedField(
         proto.MESSAGE, number=1, message=gca_model_evaluation.ModelEvaluation,
     )
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
