@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,9 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import os
 import mock
+import packaging.version
 
 import grpc
 from grpc.experimental import aio
@@ -24,16 +23,16 @@ import math
 import pytest
 from proto.marshal.rules.dates import DurationRule, TimestampRule
 
-from google import auth
+
 from google.api_core import client_options
-from google.api_core import exceptions
+from google.api_core import exceptions as core_exceptions
 from google.api_core import future
 from google.api_core import gapic_v1
 from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
 from google.api_core import operation_async  # type: ignore
 from google.api_core import operations_v1
-from google.auth import credentials
+from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.automl_v1beta1.services.prediction_service import (
     PredictionServiceAsyncClient,
@@ -42,6 +41,9 @@ from google.cloud.automl_v1beta1.services.prediction_service import (
     PredictionServiceClient,
 )
 from google.cloud.automl_v1beta1.services.prediction_service import transports
+from google.cloud.automl_v1beta1.services.prediction_service.transports.base import (
+    _GOOGLE_AUTH_VERSION,
+)
 from google.cloud.automl_v1beta1.types import annotation_payload
 from google.cloud.automl_v1beta1.types import data_items
 from google.cloud.automl_v1beta1.types import geometry
@@ -51,7 +53,22 @@ from google.cloud.automl_v1beta1.types import prediction_service
 from google.cloud.automl_v1beta1.types import text_segment
 from google.longrunning import operations_pb2
 from google.oauth2 import service_account
-from google.protobuf import struct_pb2 as struct  # type: ignore
+from google.protobuf import struct_pb2  # type: ignore
+import google.auth
+
+
+# TODO(busunkim): Once google-auth >= 1.25.0 is required transitively
+# through google-api-core:
+# - Delete the auth "less than" test cases
+# - Delete these pytest markers (Make the "greater than or equal to" tests the default).
+requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth < 1.25.0",
+)
+requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) < packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth >= 1.25.0",
+)
 
 
 def client_cert_source_callback():
@@ -103,7 +120,7 @@ def test__get_default_mtls_endpoint():
     "client_class", [PredictionServiceClient, PredictionServiceAsyncClient,]
 )
 def test_prediction_service_client_from_service_account_info(client_class):
-    creds = credentials.AnonymousCredentials()
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
@@ -116,11 +133,41 @@ def test_prediction_service_client_from_service_account_info(client_class):
         assert client.transport._host == "automl.googleapis.com:443"
 
 
+@pytest.mark.parametrize(
+    "client_class", [PredictionServiceClient, PredictionServiceAsyncClient,]
+)
+def test_prediction_service_client_service_account_always_use_jwt(client_class):
+    with mock.patch.object(
+        service_account.Credentials, "with_always_use_jwt_access", create=True
+    ) as use_jwt:
+        creds = service_account.Credentials(None, None, None)
+        client = client_class(credentials=creds)
+        use_jwt.assert_not_called()
+
+
+@pytest.mark.parametrize(
+    "transport_class,transport_name",
+    [
+        (transports.PredictionServiceGrpcTransport, "grpc"),
+        (transports.PredictionServiceGrpcAsyncIOTransport, "grpc_asyncio"),
+    ],
+)
+def test_prediction_service_client_service_account_always_use_jwt_true(
+    transport_class, transport_name
+):
+    with mock.patch.object(
+        service_account.Credentials, "with_always_use_jwt_access", create=True
+    ) as use_jwt:
+        creds = service_account.Credentials(None, None, None)
+        transport = transport_class(credentials=creds, always_use_jwt_access=True)
+        use_jwt.assert_called_once_with(True)
+
+
 @pytest.mark.parametrize(
     "client_class", [PredictionServiceClient, PredictionServiceAsyncClient,]
 )
 def test_prediction_service_client_from_service_account_file(client_class):
-    creds = credentials.AnonymousCredentials()
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
@@ -173,7 +220,7 @@ def test_prediction_service_client_client_options(
 ):
     # Check that if channel is provided we won't create a new one.
     with mock.patch.object(PredictionServiceClient, "get_transport_class") as gtc:
-        transport = transport_class(credentials=credentials.AnonymousCredentials())
+        transport = transport_class(credentials=ga_credentials.AnonymousCredentials())
         client = client_class(transport=transport)
         gtc.assert_not_called()
 
@@ -471,7 +518,7 @@ def test_predict(
     transport: str = "grpc", request_type=prediction_service.PredictRequest
 ):
     client = PredictionServiceClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -482,17 +529,14 @@ def test_predict(
     with mock.patch.object(type(client.transport.predict), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = prediction_service.PredictResponse()
-
         response = client.predict(request)
 
         # Establish that the underlying gRPC stub method was called.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == prediction_service.PredictRequest()
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, prediction_service.PredictResponse)
 
 
@@ -504,7 +548,7 @@ def test_predict_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = PredictionServiceClient(
-        credentials=credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -512,7 +556,6 @@ def test_predict_empty_call():
         client.predict()
         call.assert_called()
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == prediction_service.PredictRequest()
 
 
@@ -521,7 +564,7 @@ async def test_predict_async(
     transport: str = "grpc_asyncio", request_type=prediction_service.PredictRequest
 ):
     client = PredictionServiceAsyncClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -534,13 +577,11 @@ async def test_predict_async(
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             prediction_service.PredictResponse()
         )
-
         response = await client.predict(request)
 
         # Establish that the underlying gRPC stub method was called.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == prediction_service.PredictRequest()
 
     # Establish that the response is the type that we expect.
@@ -553,17 +594,17 @@ async def test_predict_async_from_dict():
 
 
 def test_predict_field_headers():
-    client = PredictionServiceClient(credentials=credentials.AnonymousCredentials(),)
+    client = PredictionServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = prediction_service.PredictRequest()
+
     request.name = "name/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.predict), "__call__") as call:
         call.return_value = prediction_service.PredictResponse()
-
         client.predict(request)
 
         # Establish that the underlying gRPC stub method was called.
@@ -579,12 +620,13 @@ def test_predict_field_headers():
 @pytest.mark.asyncio
 async def test_predict_field_headers_async():
     client = PredictionServiceAsyncClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = prediction_service.PredictRequest()
+
     request.name = "name/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -592,7 +634,6 @@ async def test_predict_field_headers_async():
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             prediction_service.PredictResponse()
         )
-
         await client.predict(request)
 
         # Establish that the underlying gRPC stub method was called.
@@ -606,13 +647,12 @@ async def test_predict_field_headers_async():
 
 
 def test_predict_flattened():
-    client = PredictionServiceClient(credentials=credentials.AnonymousCredentials(),)
+    client = PredictionServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.predict), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = prediction_service.PredictResponse()
-
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         client.predict(
@@ -627,18 +667,15 @@ def test_predict_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-
         assert args[0].name == "name_value"
-
         assert args[0].payload == data_items.ExamplePayload(
             image=data_items.Image(image_bytes=b"image_bytes_blob")
         )
-
         assert args[0].params == {"key_value": "value_value"}
 
 
 def test_predict_flattened_error():
-    client = PredictionServiceClient(credentials=credentials.AnonymousCredentials(),)
+    client = PredictionServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -656,7 +693,7 @@ def test_predict_flattened_error():
 @pytest.mark.asyncio
 async def test_predict_flattened_async():
     client = PredictionServiceAsyncClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -681,20 +718,17 @@ async def test_predict_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-
         assert args[0].name == "name_value"
-
         assert args[0].payload == data_items.ExamplePayload(
             image=data_items.Image(image_bytes=b"image_bytes_blob")
         )
-
         assert args[0].params == {"key_value": "value_value"}
 
 
 @pytest.mark.asyncio
 async def test_predict_flattened_error_async():
     client = PredictionServiceAsyncClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Attempting to call a method with both a request object and flattened
@@ -714,7 +748,7 @@ def test_batch_predict(
     transport: str = "grpc", request_type=prediction_service.BatchPredictRequest
 ):
     client = PredictionServiceClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -725,13 +759,11 @@ def test_batch_predict(
     with mock.patch.object(type(client.transport.batch_predict), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = operations_pb2.Operation(name="operations/spam")
-
         response = client.batch_predict(request)
 
         # Establish that the underlying gRPC stub method was called.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == prediction_service.BatchPredictRequest()
 
     # Establish that the response is the type that we expect.
@@ -746,7 +778,7 @@ def test_batch_predict_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = PredictionServiceClient(
-        credentials=credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -754,7 +786,6 @@ def test_batch_predict_empty_call():
         client.batch_predict()
         call.assert_called()
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == prediction_service.BatchPredictRequest()
 
 
@@ -763,7 +794,7 @@ async def test_batch_predict_async(
     transport: str = "grpc_asyncio", request_type=prediction_service.BatchPredictRequest
 ):
     client = PredictionServiceAsyncClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -776,13 +807,11 @@ async def test_batch_predict_async(
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             operations_pb2.Operation(name="operations/spam")
         )
-
         response = await client.batch_predict(request)
 
         # Establish that the underlying gRPC stub method was called.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == prediction_service.BatchPredictRequest()
 
     # Establish that the response is the type that we expect.
@@ -795,17 +824,17 @@ async def test_batch_predict_async_from_dict():
 
 
 def test_batch_predict_field_headers():
-    client = PredictionServiceClient(credentials=credentials.AnonymousCredentials(),)
+    client = PredictionServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = prediction_service.BatchPredictRequest()
+
     request.name = "name/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.batch_predict), "__call__") as call:
         call.return_value = operations_pb2.Operation(name="operations/op")
-
         client.batch_predict(request)
 
         # Establish that the underlying gRPC stub method was called.
@@ -821,12 +850,13 @@ def test_batch_predict_field_headers():
 @pytest.mark.asyncio
 async def test_batch_predict_field_headers_async():
     client = PredictionServiceAsyncClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = prediction_service.BatchPredictRequest()
+
     request.name = "name/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -834,7 +864,6 @@ async def test_batch_predict_field_headers_async():
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             operations_pb2.Operation(name="operations/op")
         )
-
         await client.batch_predict(request)
 
         # Establish that the underlying gRPC stub method was called.
@@ -848,13 +877,12 @@ async def test_batch_predict_field_headers_async():
 
 
 def test_batch_predict_flattened():
-    client = PredictionServiceClient(credentials=credentials.AnonymousCredentials(),)
+    client = PredictionServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.batch_predict), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = operations_pb2.Operation(name="operations/op")
-
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         client.batch_predict(
@@ -874,24 +902,20 @@ def test_batch_predict_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-
         assert args[0].name == "name_value"
-
         assert args[0].input_config == io.BatchPredictInputConfig(
             gcs_source=io.GcsSource(input_uris=["input_uris_value"])
         )
-
         assert args[0].output_config == io.BatchPredictOutputConfig(
             gcs_destination=io.GcsDestination(
                 output_uri_prefix="output_uri_prefix_value"
             )
         )
-
         assert args[0].params == {"key_value": "value_value"}
 
 
 def test_batch_predict_flattened_error():
-    client = PredictionServiceClient(credentials=credentials.AnonymousCredentials(),)
+    client = PredictionServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -914,7 +938,7 @@ def test_batch_predict_flattened_error():
 @pytest.mark.asyncio
 async def test_batch_predict_flattened_async():
     client = PredictionServiceAsyncClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -944,26 +968,22 @@ async def test_batch_predict_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-
         assert args[0].name == "name_value"
-
         assert args[0].input_config == io.BatchPredictInputConfig(
             gcs_source=io.GcsSource(input_uris=["input_uris_value"])
         )
-
         assert args[0].output_config == io.BatchPredictOutputConfig(
             gcs_destination=io.GcsDestination(
                 output_uri_prefix="output_uri_prefix_value"
             )
         )
-
         assert args[0].params == {"key_value": "value_value"}
 
 
 @pytest.mark.asyncio
 async def test_batch_predict_flattened_error_async():
     client = PredictionServiceAsyncClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Attempting to call a method with both a request object and flattened
@@ -987,16 +1007,16 @@ async def test_batch_predict_flattened_error_async():
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.PredictionServiceGrpcTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = PredictionServiceClient(
-            credentials=credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
     transport = transports.PredictionServiceGrpcTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = PredictionServiceClient(
@@ -1006,7 +1026,7 @@ def test_credentials_transport_error():
 
     # It is an error to provide scopes and a transport instance.
     transport = transports.PredictionServiceGrpcTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = PredictionServiceClient(
@@ -1017,7 +1037,7 @@ def test_credentials_transport_error():
 def test_transport_instance():
     # A client may be instantiated with a custom transport instance.
     transport = transports.PredictionServiceGrpcTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     client = PredictionServiceClient(transport=transport)
     assert client.transport is transport
@@ -1026,13 +1046,13 @@ def test_transport_instance():
 def test_transport_get_channel():
     # A client may be instantiated with a custom transport instance.
     transport = transports.PredictionServiceGrpcTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     channel = transport.grpc_channel
     assert channel
 
     transport = transports.PredictionServiceGrpcAsyncIOTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     channel = transport.grpc_channel
     assert channel
@@ -1047,23 +1067,23 @@ def test_transport_get_channel():
 )
 def test_transport_adc(transport_class):
     # Test default credentials are used if not provided.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default") as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport_class()
         adc.assert_called_once()
 
 
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = PredictionServiceClient(credentials=credentials.AnonymousCredentials(),)
+    client = PredictionServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
     assert isinstance(client.transport, transports.PredictionServiceGrpcTransport,)
 
 
 def test_prediction_service_base_transport_error():
     # Passing both a credentials object and credentials_file should raise an error
-    with pytest.raises(exceptions.DuplicateCredentialArgs):
+    with pytest.raises(core_exceptions.DuplicateCredentialArgs):
         transport = transports.PredictionServiceTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
             credentials_file="credentials.json",
         )
 
@@ -1075,7 +1095,7 @@ def test_prediction_service_base_transport():
     ) as Transport:
         Transport.return_value = None
         transport = transports.PredictionServiceTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
         )
 
     # Every method on the transport should just blindly
@@ -1094,15 +1114,37 @@ def test_prediction_service_base_transport():
         transport.operations_client
 
 
+@requires_google_auth_gte_1_25_0
 def test_prediction_service_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
     with mock.patch.object(
-        auth, "load_credentials_from_file"
+        google.auth, "load_credentials_from_file", autospec=True
     ) as load_creds, mock.patch(
         "google.cloud.automl_v1beta1.services.prediction_service.transports.PredictionServiceTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        load_creds.return_value = (credentials.AnonymousCredentials(), None)
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport = transports.PredictionServiceTransport(
+            credentials_file="credentials.json", quota_project_id="octopus",
+        )
+        load_creds.assert_called_once_with(
+            "credentials.json",
+            scopes=None,
+            default_scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            quota_project_id="octopus",
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_prediction_service_base_transport_with_credentials_file_old_google_auth():
+    # Instantiate the base transport with a credentials file
+    with mock.patch.object(
+        google.auth, "load_credentials_from_file", autospec=True
+    ) as load_creds, mock.patch(
+        "google.cloud.automl_v1beta1.services.prediction_service.transports.PredictionServiceTransport._prep_wrapped_messages"
+    ) as Transport:
+        Transport.return_value = None
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.PredictionServiceTransport(
             credentials_file="credentials.json", quota_project_id="octopus",
         )
@@ -1115,19 +1157,33 @@ def test_prediction_service_base_transport_with_credentials_file():
 
 def test_prediction_service_base_transport_with_adc():
     # Test the default credentials are used if credentials and credentials_file are None.
-    with mock.patch.object(auth, "default") as adc, mock.patch(
+    with mock.patch.object(google.auth, "default", autospec=True) as adc, mock.patch(
         "google.cloud.automl_v1beta1.services.prediction_service.transports.PredictionServiceTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.PredictionServiceTransport()
         adc.assert_called_once()
 
 
+@requires_google_auth_gte_1_25_0
 def test_prediction_service_auth_adc():
     # If no credentials are provided, we should use ADC credentials.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        PredictionServiceClient()
+        adc.assert_called_once_with(
+            scopes=None,
+            default_scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            quota_project_id=None,
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_prediction_service_auth_adc_old_google_auth():
+    # If no credentials are provided, we should use ADC credentials.
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         PredictionServiceClient()
         adc.assert_called_once_with(
             scopes=("https://www.googleapis.com/auth/cloud-platform",),
@@ -1135,20 +1191,82 @@ def test_prediction_service_auth_adc():
         )
 
 
-def test_prediction_service_transport_auth_adc():
+@pytest.mark.parametrize(
+    "transport_class",
+    [
+        transports.PredictionServiceGrpcTransport,
+        transports.PredictionServiceGrpcAsyncIOTransport,
+    ],
+)
+@requires_google_auth_gte_1_25_0
+def test_prediction_service_transport_auth_adc(transport_class):
     # If credentials and host are not provided, the transport class should use
     # ADC credentials.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
-        transports.PredictionServiceGrpcTransport(
-            host="squid.clam.whelk", quota_project_id="octopus"
-        )
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport_class(quota_project_id="octopus", scopes=["1", "2"])
         adc.assert_called_once_with(
-            scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            scopes=["1", "2"],
+            default_scopes=("https://www.googleapis.com/auth/cloud-platform",),
             quota_project_id="octopus",
         )
 
 
+@pytest.mark.parametrize(
+    "transport_class",
+    [
+        transports.PredictionServiceGrpcTransport,
+        transports.PredictionServiceGrpcAsyncIOTransport,
+    ],
+)
+@requires_google_auth_lt_1_25_0
+def test_prediction_service_transport_auth_adc_old_google_auth(transport_class):
+    # If credentials and host are not provided, the transport class should use
+    # ADC credentials.
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport_class(quota_project_id="octopus")
+        adc.assert_called_once_with(
+            scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            quota_project_id="octopus",
+        )
+
+
+@pytest.mark.parametrize(
+    "transport_class,grpc_helpers",
+    [
+        (transports.PredictionServiceGrpcTransport, grpc_helpers),
+        (transports.PredictionServiceGrpcAsyncIOTransport, grpc_helpers_async),
+    ],
+)
+def test_prediction_service_transport_create_channel(transport_class, grpc_helpers):
+    # If credentials and host are not provided, the transport class should use
+    # ADC credentials.
+    with mock.patch.object(
+        google.auth, "default", autospec=True
+    ) as adc, mock.patch.object(
+        grpc_helpers, "create_channel", autospec=True
+    ) as create_channel:
+        creds = ga_credentials.AnonymousCredentials()
+        adc.return_value = (creds, None)
+        transport_class(quota_project_id="octopus", scopes=["1", "2"])
+
+        create_channel.assert_called_with(
+            "automl.googleapis.com:443",
+            credentials=creds,
+            credentials_file=None,
+            quota_project_id="octopus",
+            default_scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            scopes=["1", "2"],
+            default_host="automl.googleapis.com",
+            ssl_credentials=None,
+            options=[
+                ("grpc.max_send_message_length", -1),
+                ("grpc.max_receive_message_length", -1),
+            ],
+        )
+
+
 @pytest.mark.parametrize(
     "transport_class",
     [
@@ -1157,7 +1275,7 @@ def test_prediction_service_transport_auth_adc():
     ],
 )
 def test_prediction_service_grpc_transport_client_cert_source_for_mtls(transport_class):
-    cred = credentials.AnonymousCredentials()
+    cred = ga_credentials.AnonymousCredentials()
 
     # Check ssl_channel_credentials is used if provided.
     with mock.patch.object(transport_class, "create_channel") as mock_create_channel:
@@ -1171,7 +1289,7 @@ def test_prediction_service_grpc_transport_client_cert_source_for_mtls(transport
             "squid.clam.whelk:443",
             credentials=cred,
             credentials_file=None,
-            scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            scopes=None,
             ssl_credentials=mock_ssl_channel_creds,
             quota_project_id=None,
             options=[
@@ -1196,7 +1314,7 @@ def test_prediction_service_grpc_transport_client_cert_source_for_mtls(transport
 
 def test_prediction_service_host_no_port():
     client = PredictionServiceClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="automl.googleapis.com"
         ),
@@ -1206,7 +1324,7 @@ def test_prediction_service_host_no_port():
 
 def test_prediction_service_host_with_port():
     client = PredictionServiceClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="automl.googleapis.com:8000"
         ),
@@ -1262,9 +1380,9 @@ def test_prediction_service_transport_channel_mtls_with_client_cert_source(
             mock_grpc_channel = mock.Mock()
             grpc_create_channel.return_value = mock_grpc_channel
 
-            cred = credentials.AnonymousCredentials()
+            cred = ga_credentials.AnonymousCredentials()
             with pytest.warns(DeprecationWarning):
-                with mock.patch.object(auth, "default") as adc:
+                with mock.patch.object(google.auth, "default") as adc:
                     adc.return_value = (cred, None)
                     transport = transport_class(
                         host="squid.clam.whelk",
@@ -1280,7 +1398,7 @@ def test_prediction_service_transport_channel_mtls_with_client_cert_source(
                 "mtls.squid.clam.whelk:443",
                 credentials=cred,
                 credentials_file=None,
-                scopes=("https://www.googleapis.com/auth/cloud-platform",),
+                scopes=None,
                 ssl_credentials=mock_ssl_cred,
                 quota_project_id=None,
                 options=[
@@ -1327,7 +1445,7 @@ def test_prediction_service_transport_channel_mtls_with_adc(transport_class):
                 "mtls.squid.clam.whelk:443",
                 credentials=mock_cred,
                 credentials_file=None,
-                scopes=("https://www.googleapis.com/auth/cloud-platform",),
+                scopes=None,
                 ssl_credentials=mock_ssl_cred,
                 quota_project_id=None,
                 options=[
@@ -1340,7 +1458,7 @@ def test_prediction_service_transport_channel_mtls_with_adc(transport_class):
 
 def test_prediction_service_grpc_lro_client():
     client = PredictionServiceClient(
-        credentials=credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
     )
     transport = client.transport
 
@@ -1353,7 +1471,7 @@ def test_prediction_service_grpc_lro_client():
 
 def test_prediction_service_grpc_lro_async_client():
     client = PredictionServiceAsyncClient(
-        credentials=credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
     )
     transport = client.transport
 
@@ -1368,7 +1486,6 @@ def test_model_path():
     project = "squid"
     location = "clam"
     model = "whelk"
-
     expected = "projects/{project}/locations/{location}/models/{model}".format(
         project=project, location=location, model=model,
     )
@@ -1391,7 +1508,6 @@ def test_parse_model_path():
 
 def test_common_billing_account_path():
     billing_account = "cuttlefish"
-
     expected = "billingAccounts/{billing_account}".format(
         billing_account=billing_account,
     )
@@ -1412,7 +1528,6 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "winkle"
-
     expected = "folders/{folder}".format(folder=folder,)
     actual = PredictionServiceClient.common_folder_path(folder)
     assert expected == actual
@@ -1431,7 +1546,6 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "scallop"
-
     expected = "organizations/{organization}".format(organization=organization,)
     actual = PredictionServiceClient.common_organization_path(organization)
     assert expected == actual
@@ -1450,7 +1564,6 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "squid"
-
     expected = "projects/{project}".format(project=project,)
     actual = PredictionServiceClient.common_project_path(project)
     assert expected == actual
@@ -1470,7 +1583,6 @@ def test_parse_common_project_path():
 def test_common_location_path():
     project = "whelk"
     location = "octopus"
-
     expected = "projects/{project}/locations/{location}".format(
         project=project, location=location,
     )
@@ -1497,7 +1609,7 @@ def test_client_withDEFAULT_CLIENT_INFO():
         transports.PredictionServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = PredictionServiceClient(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1506,6 +1618,6 @@ def test_client_withDEFAULT_CLIENT_INFO():
     ) as prep:
         transport_class = PredictionServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
